@@ -1,8 +1,12 @@
+//! Serializes Bencode data.
+
 use crate::error::{Error, Result};
-use itoa;
 use serde::{ser, Serialize};
-use std::collections::BTreeMap;
-use std::io;
+
+#[cfg(all(feature = "alloc", not(feature = "std")))]
+use alloc::{collections::BTreeMap, vec::Vec};
+#[cfg(feature = "std")]
+use std::{collections::BTreeMap, io, vec::Vec};
 
 /// Serializes an instance of `T` into the writer `W` as `Bencode` data.
 ///
@@ -21,7 +25,7 @@ where
     Ok(())
 }
 
-/// Serializes an instance of `T` into a new `Vec` as `Bencode` data
+/// Serializes an instance of `T` into a new `Vec` as `Bencode` data.
 ///
 /// # Errors
 ///
@@ -308,8 +312,7 @@ where
 }
 
 /// A serializer for writing map data.
-///
-/// Not intended to be instantiated by crate users.
+#[doc(hidden)]
 #[derive(Debug)]
 pub struct SerializeMap<'a, W> {
     ser: &'a mut Serializer<W>,
@@ -594,6 +597,11 @@ mod tests {
     use super::*;
     use serde_bytes::ByteBuf;
 
+    #[cfg(all(feature = "alloc", not(feature = "std")))]
+    use alloc::string::String;
+    #[cfg(feature = "std")]
+    use std::string::String;
+
     #[test]
     fn test_serialize_bool() {
         assert!(match to_vec(&true) {
